pub enum ProblemType {
Default,
Interactive,
RunTwice,
RunTwiceInteractive,
RunTwiceFirstInteractive,
RunTwiceSecondInteractive,
}Expand description
Problem’s type
Variants
Default
Default problem
Interactive
Interactive problem
RunTwice
Run-twice problem
RunTwiceInteractive
Run-twice problem, where both runs are interactive
RunTwiceFirstInteractive
Run-twice problem, where the first run is interactive, and the second run is a default one
RunTwiceSecondInteractive
Run-twice problem, where the first run is a default one, and the second run is interactive