pub struct Subgroup {
pub type: SubgroupType,
pub tests: Vec<i32>,
pub score: Option<i32>,
pub score_per_test: Option<i32>,
pub depends_on: Vec<usize>,
}Expand description
Testing subgroup
Fields
type: SubgroupTypeSubgroup’s type
tests: Vec<i32>Array of tests’ indexes of the subgroup
score: Option<i32>Maximum score which can be obtained from the subgroup
score_per_test: Option<i32>Maximum score which can be obtained from the each of subgroup’s tests
depends_on: Vec<usize>Indexes of the subgroups, all of them must have Ok verdict to test on this subgroup.
Also, they must be less than index of this subgroup